Deals - Plumdistrict.com
Description: Find deals for National Deals restaurants, bars, spas, events and more.
Keywords: national deals coupons, discount restaurant coupons, massage coupons, national deals, group buying, plumdistrict, plumdistrict.com

National Deals
Alabama

- Mobile
- Montgomery

Arizona

- Phoenix
- Tucson

Arkansas

- Little Rock

California

- East Bay
- Fresno
- Los Angeles/ventura County
- Orange County
- Palm Springs
- Sacramento
- San Diego
- San Fernando Valley
- San Francisco
- San Jose
- Santa Clarita
- Temecula

Colorado

- Colorado Springs
- Denver

Connecticut

- Hartford

D. C.

- Washington D. C.

Florida

- Fort-lauderdale
- Ft. Myers
- Jacksonville
- Miami
- Orlando
- St. Petersburg
- Tallahassee
- Tampa Bay

Georgia

- Athens
- Atlanta

Hawaii

- Big Island
- Honolulu
- Maui

Idaho

- Boise

Illinois

- Chicago
- Northwest Suburbs - Chicago

Indiana

- Ft. Wayne
- Indianapolis

Iowa

- Cedar Rapids
- Cedar Valley
- Sioux City

Kansas

- Johnson County
- Lawrence
- Manhattan - Kansas
- Topeka

Kentucky

- Louisville

Louisiana

- Alexandria Louisiana
- Baton Rouge
- Lafayette
- Lake Charles
- New Orleans
- Shreveport

Maine

- Portland Maine

Maryland

- Baltimore

Massachusetts

- Boston

Michigan

- Detroit
- Grand Rapids

Minnesota

- Minneapolis / St Paul
- Rochester - Minnesota

Mississippi

- Greenwood
- Gulfport

Missouri

- Kansas City
- Springfield
- St. Louis

National

- National Deals
- Pets

Nebraska

- Omaha

Nevada

- Las Vegas

New Jersey

- Atlantic City

New Mexico

- Albuquerque

New York

- Albany
- Buffalo
- New York City
- Poughkeepsie
- Rochester
- Syracuse
- Utica

North Carolina

- Charlotte
- Raleigh

Ohio

- Cincinnati
- Cleveland
- Columbus
- Dayton

Oklahoma

- Oklahoma City
- Tulsa

Oregon

- Eugene
- Portland

Pennsylvania

- Harrisburg
- Philadelphia
- Pittsburgh

Rhode Island

- Providence

South Carolina

- Charleston

South Dakota

- Sioux Falls

Tennessee

- Chattanooga
- Knoxville
- Memphis
- Nashville

Texas

- Amarillo
- Austin
- Beaumont
- Dallas
- El Paso
- Fort Worth
- Golden Triangle
- Houston
- Lubbock
- Odessa
- San Antonio
- Sugar Land

Utah

- Salt Lake City

Virginia

- Norfolk
- Richmond

Washington

- Seattle
- Tacoma

Wisconsin

- Green Bay
- Milwaukee

# $19 for a Set of Car Storage Seat Pocket Car Seats - Shipping Included

Set of Car Storage Seat Pocket Car Seats

## $1900

VIEW DEAL

- Retail $29.00
- You save 34%
- You Pay $19.00

Like this deal? Share it!

#### $165 for a Refurbished 16GB Apple iPad Wi-Fi Only - Shipping Included ($449...

Refurbished 16GB 1st Generation App...
National
$165.00 $449.00
VIEW DEAL

#### $39 for a Long Fleece-Lined Hoodie - Shipping Included

Long Fleece-Lined Hoodie
National
$39.00 $80.00
VIEW DEAL

#### $16 for an Antique Silver Natural Tibet Turquoise Necklace - Shipping Inclu...

Antique Silver Natural Tibet Turquo...
National
$16.00 $225.00
VIEW DEAL

#### $74 for a Refurbished Jawbone JAMBOX Portable Rechargeable Bluetooth Speake...

Refurbished Jawbone JAMBOX Portable...
National
$74.00 $199.00
VIEW DEAL

#### $39 for a 170 Degree Wide Angle Rear View Car Camera - Shipping Included

170 Degree Wide Angle Rear View Car...
National
$39.00 $129.00
VIEW DEAL

#### $14 for a Hand Stamped Bracelet - Multiple Options - Shipping Included

Hand Stamped Bracelet
National
$14.00 $29.99
VIEW DEAL

#### $24 for a Frozen 100% Cotton Bath Towel - Shipping Included

Frozen 100% Cotton Bath Towel
National
$24.00 $49.00
VIEW DEAL

#### $15 for Cutlery Herb Scissors - Shipping Included

Cutlery Herb Scissors
National
$15.00 $29.00
VIEW DEAL

#### $20 for Four Christmas Wine Bottle Covers - Shipping Included

Four Christmas Wine Bottle Covers
National
$20.00 $49.99
VIEW DEAL

#### $15 for a 5-Pack of Reusable Hand Warmers - Shipping Included

5-Pack of Reusable Hand Warmers
National
$15.00 $29.99
VIEW DEAL

#### $35 for a JBL OnBeat Micro Speaker Dock for iPhone - Shipping Included

JBL OnBeat Micro Speaker Dock for i...
National
$35.00 $90.00
VIEW DEAL

#### $16 for the "Happy Holidays" Festive Charm Bracelet - Shipping Included...

Happy Holidays Festive Charm Bracel...
National
$16.00 $75.00
VIEW DEAL

#### $16 for a Plaid Shawl - Shipping Included

Plaid Shawl
National
$16.00 $32.00
VIEW DEAL

#### $23 for Trendy Mitten Hoody Scarf - Shipping Included

Trendy Mitten Hoody Scarf
National
$23.00 $40.00
VIEW DEAL

#### $89 for a Drone with HD Camera - Shipping Included

Drone with HD Camera
National
$89.00 $199.00
VIEW DEAL

#### $15 for a "Mother and Daughter" Silver-Plated Pendant - Shipping Included...

Mother and Daughter Silver-Plated P...
National
$15.00 $95.00
VIEW DEAL

#### $55 for a Wireless Bluetooth Speaker with Colorful LED - Shipping Included

Wireless Bluetooth Speaker with Col...
National
$55.00 $79.00
VIEW DEAL

#### $12 for a Pair of iGloves for Touchscreen Devices - Shipping Included

Pair of iGloves for Touchscreen Dev...
National
$12.00 $23.00
VIEW DEAL

#### $16 for Fun Holiday Hats - Shipping Included

Fun Holiday Hats
National
$16.00 $34.00
VIEW DEAL

#### $9 for a 5-Pack of LED Helicopter Shooters - Shipping Included

5-Pack of LED Helicopter Shooters
National
$9.00 $39.99
VIEW DEAL

#### $119 for the HYPER FX-183 Drone Copter with HD camera & LED for Night Fligh...

HYPER FX-183 Drone Copter with HD c...
National
$119.00 $299.00
VIEW DEAL

#### $99 for the Jawbone JAMBOX Limited Edition Portable Bluetooth Speaker - Shi...

Jawbone JAMBOX Limited Edition Port...
National
$99.00 $199.00
VIEW DEAL

#### $19 for a 10-Pack Holiday Dominican Cigar Sampler

StogieBoys.com
National
$19.00 $40.00
VIEW DEAL

#### $18 for 100 Solar LED Holiday Lights - Shipping Included

100 Solar LED Holiday Lights
National
$18.00 $59.00
VIEW DEAL

#### $27 for a Slouchy Sweater - 3 Color Options - Shipping Included

Slouchy Sweater
National
$27.00 $55.00
VIEW DEAL

#### $199.99 for the Jawbone BIG JAMBOX - Shipping Included

Jawbone BIG JAMBOX
National
$199.99 $299.99
VIEW DEAL

#### $99 for a Syma X5C Quadcopter Drone with HD Camera - Shipping Included

Syma X5C Quadcopter Drone with HD C...
National
$99.00 $199.00
VIEW DEAL

#### $42 for a Double Breasted Peacoat - Shipping Included

A-Line Double Breasted Peacoat
National
$42.00 $59.00
VIEW DEAL

#### $15 for the Original Apple EarPods - Shipping Included

Apple EarPods with Remote and Mic
National
$15.00 $30.00
VIEW DEAL

#### $17 for a Fleece Heated Scarf - 4 Color Options - Shipping Included

Fleece Heated Scarf
National
$17.00 $39.00
VIEW DEAL

#### $49 for 3 Days/2 Nights in Any US City + Airfare Credit or Dinner

3 Days/2 Nights + Airfare Credit or...
National
$49.00 $250.00
VIEW DEAL

#### $21 for a Santa Bathroom Set - Shipping Included

Santa Toilet Seat Cover and Rug Set
National
$21.00 $39.00
VIEW DEAL

#### $20 for a Women’s Neckline Bow Long Sleeve Shirt - Shipping Included

Women’s Neckline Bow Long Sleeve ...
National
$20.00 $49.00
VIEW DEAL

#### $30 for a 50lb Draw Fiberglass Pistol Crossbow with 3 Bolts - Shipping Incl...

50lb. Draw Fiberglass Pistol Crossb...
National
$30.00 $69.00
VIEW DEAL

#### $22 for the Arm Slimming Compression Wrap with Posture Support - Shipping I...

Arm Slimming Compression Wrap with ...
National
$22.00 $39.99
VIEW DEAL

#### $13 for the NEW "I Love You to the Moon & Back" Necklace - Shipping Include...

NEW
National
$13.00 $65.00
VIEW DEAL

#### $24 for a Frozen Princess Elsa-Inspired Dress - Shipping Included

Frozen Princess Elsa Inspired Dress
National
$24.00 $59.00
VIEW DEAL

#### $17 for Digital Camera Binoculars by Innovage - Shipping Included

10 x 25 Digital Camera Binoculars b...
National
$17.00 $59.99
VIEW DEAL

#### $17 for a Frozen LED Alarm Clock - Shipping Included

Frozen LED Alarm Clock
National
$17.00 $34.99
VIEW DEAL

#### $25 for Two 50 Caliber Bullet Bottle Openers - Shipping Included

Two 50 Caliber Bullet Bottle Opener...
National
$25.00 $59.00
VIEW DEAL

#### $14 for a Children's Learning Tablet - Shipping Included

Children's Learning Tablet
National
$14.00 $40.00
VIEW DEAL

#### $16 for the Bathroom Golf Putting Set - Shipping Included

Bathroom Golf Putting Set
National
$16.00 $39.00
VIEW DEAL

#### $39 for a Frozen 60" x 80" Coral Fleece Blanket - Shipping Included...

Frozen Fleece Blanket
National
$39.00 $99.00
VIEW DEAL

#### $28 for a Universal Water Resistant Bluetooth Behind-the-Neck Stereo Headse...

Universal Water Resistant Bluetooth...
National
$28.00 $90.00
VIEW DEAL

#### $399 for a Refurbished 13.3" MacBook - Shipping Included

Refurbished 13.3
National
$399.00 $949.00
VIEW DEAL

#### $23 for a Knitted Scarf with Sleeves - Shipping Included

Knitted Scarf with Sleeves
National
$23.00 $69.00
VIEW DEAL

#### $39 for an iPhone 6/6+ Extreme Aluminum Case - 6 Color Options - Shipping I...

Extreme Water/Dirt/Shock Proof Alum...
National
$39.00 $200.00
VIEW DEAL

#### $20 for a Batwing Top with Tank - Shipping Included

Batwing Top with Tank
National
$20.00 $49.00
VIEW DEAL

- ### Become an
  Affiliate!

  Share great local
  deals with site visitors
  and make a profit in
  the process?

- ### Feature Your
  Business!

  Reach thousands of
  people in your city
  with your own
  customized deal.

- ### Questions,
  Comments?

  Just drop us a line!
  We are here to help.

- Follow us: